gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [taler-merchant] branch master updated: use url instead of


From: gnunet
Subject: [GNUnet-SVN] [taler-merchant] branch master updated: use url instead of uri consistently
Date: Tue, 30 Jan 2018 01:38:33 +0100

This is an automated email from the git hooks/post-receive script.

dold pushed a commit to branch master
in repository merchant.

The following commit(s) were added to refs/heads/master by this push:
     new a4bff93  use url instead of uri consistently
a4bff93 is described below

commit a4bff93ef869bbcd0f425d1b424d9b307f601447
Author: Florian Dold <address@hidden>
AuthorDate: Tue Jan 30 01:38:28 2018 +0100

    use url instead of uri consistently
---
 src/backend/taler-merchant-httpd.c                 |  2 +-
 src/backend/taler-merchant-httpd_auditors.c        | 18 +++++-----
 src/backend/taler-merchant-httpd_exchanges.c       | 40 +++++++++++-----------
 src/backend/taler-merchant-httpd_exchanges.h       |  2 +-
 src/backend/taler-merchant-httpd_tip-pickup.c      | 12 +++----
 src/backend/taler-merchant-httpd_tip-query.c       |  6 ++--
 src/backend/taler-merchant-httpd_track-transfer.c  | 24 ++++++-------
 src/lib/merchant_api_common.c                      |  2 +-
 src/lib/merchant_api_common.h                      |  2 +-
 src/lib/merchant_api_history.c                     |  8 ++---
 src/lib/merchant_api_pay_abort.c                   |  6 ++--
 src/lib/merchant_api_proposal.c                    | 14 ++++----
 src/lib/merchant_api_refund.c                      | 12 +++----
 src/lib/merchant_api_tip_authorize.c               |  8 ++---
 src/lib/merchant_api_tip_pickup.c                  |  8 ++---
 src/lib/merchant_api_track_transaction.c           |  8 ++---
 src/lib/merchant_api_track_transfer.c              | 14 ++++----
 src/lib/test_merchant_api.c                        |  8 ++---
 src/lib/test_merchant_api.conf                     | 10 +++---
 .../.config/taler/merchant/wire/test.json          |  2 +-
 .../test_merchant_api_home/.config/taler/test.json |  4 +--
 src/merchant-tools/README                          |  2 +-
 22 files changed, 106 insertions(+), 106 deletions(-)

diff --git a/src/backend/taler-merchant-httpd.c 
b/src/backend/taler-merchant-httpd.c
index 2575679..0645d91 100644
--- a/src/backend/taler-merchant-httpd.c
+++ b/src/backend/taler-merchant-httpd.c
@@ -245,7 +245,7 @@ url_handler (void *cls,
       { "/tip-authorize", NULL, "application/json",
         "Only POST is allowed", 0,
         &TMH_MHD_handler_send_json_pack_error, MHD_HTTP_METHOD_NOT_ALLOWED},
-      /* legacy alias */
+      /* backwards compatibility alias for /public/tip-pickup */
       { "/tip-pickup", MHD_HTTP_METHOD_POST, "text/plain",
         NULL, 0,
         &MH_handler_tip_pickup, MHD_HTTP_OK},
diff --git a/src/backend/taler-merchant-httpd_auditors.c 
b/src/backend/taler-merchant-httpd_auditors.c
index 81b6422..8b620e0 100644
--- a/src/backend/taler-merchant-httpd_auditors.c
+++ b/src/backend/taler-merchant-httpd_auditors.c
@@ -34,9 +34,9 @@ struct Auditor
   char *name;
 
   /**
-   * Auditor's URI.
+   * Auditor's URL.
    */
-  char *uri;
+  char *url;
 
   /**
    * Public key of the auditor.
@@ -156,12 +156,12 @@ parse_auditors (void *cls,
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_string (cfg,
                                              section,
-                                             "URI",
-                                             &auditor.uri))
+                                             "URL",
+                                             &auditor.url))
   {
     GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
                                section,
-                               "URI");
+                               "URL");
     GNUNET_free (auditor.name);
     return;
   }
@@ -175,7 +175,7 @@ parse_auditors (void *cls,
                                section,
                                "PUBLIC_KEY");
     GNUNET_free (auditor.name);
-    GNUNET_free (auditor.uri);
+    GNUNET_free (auditor.url);
     return;
   }
   if (GNUNET_OK !=
@@ -188,7 +188,7 @@ parse_auditors (void *cls,
                                "PUBLIC_KEY",
                                "valid public key");
     GNUNET_free (auditor.name);
-    GNUNET_free (auditor.uri);
+    GNUNET_free (auditor.url);
     GNUNET_free (pks);
     return;
   }
@@ -225,7 +225,7 @@ TMH_AUDITORS_init (const struct GNUNET_CONFIGURATION_Handle 
*cfg)
                                           json_pack ("{s:s, s:o, s:s}",
                                                      "name", 
auditors[cnt].name,
                                                      "auditor_pub", 
GNUNET_JSON_from_data_auto (&auditors[cnt].public_key),
-                                                     "uri", 
auditors[cnt].uri)));
+                                                     "url", 
auditors[cnt].url)));
   return nauditors;
 }
 
@@ -241,7 +241,7 @@ TMH_AUDITORS_done ()
   for (unsigned int i=0;i<nauditors;i++)
   {
     GNUNET_free (auditors[i].name);
-    GNUNET_free (auditors[i].uri);
+    GNUNET_free (auditors[i].url);
   }
   GNUNET_free_non_null (auditors);
   auditors = NULL;
diff --git a/src/backend/taler-merchant-httpd_exchanges.c 
b/src/backend/taler-merchant-httpd_exchanges.c
index 4484689..c82e831 100644
--- a/src/backend/taler-merchant-httpd_exchanges.c
+++ b/src/backend/taler-merchant-httpd_exchanges.c
@@ -153,9 +153,9 @@ struct Exchange
   struct TMH_EXCHANGES_FindOperation *fo_tail;
 
   /**
-   * (base) URI of the exchange.
+   * (base) URL of the exchange.
    */
-  char *uri;
+  char *url;
 
   /**
    * A connection to this exchange
@@ -279,14 +279,14 @@ retry_exchange (void *cls)
   exchange->retry_task = NULL;
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Connecting to exchange exchange %s in retry_exchange\n",
-              exchange->uri);
+              exchange->url);
   if (NULL != exchange->conn)
   {
     TALER_EXCHANGE_disconnect (exchange->conn);
     exchange->conn = NULL;
   }
   exchange->conn = TALER_EXCHANGE_connect (merchant_curl_ctx,
-                                           exchange->uri,
+                                           exchange->url,
                                            &keys_mgmt_cb,
                                            exchange,
                                            TALER_EXCHANGE_OPTION_END);
@@ -565,7 +565,7 @@ handle_wire_data (void *cls,
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 "Failed to obtain /wire details from `%s': %d\n",
-                exchange->uri,
+                exchange->url,
                 ec);
     return;
   }
@@ -685,13 +685,13 @@ keys_mgmt_cb (void *cls,
       /* Give up, log hard error. */
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                  "Exchange `%s' runs an incompatible more recent version of 
the Taler protocol. Will not retry. This client may need to be updated.\n",
-                 exchange->uri);
+                 exchange->url);
       return;
     }
     exchange->retry_delay = RETRY_BACKOFF (exchange->retry_delay);
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 "Failed to fetch /keys from `%s', retrying in %s\n",
-                exchange->uri,
+                exchange->url,
                 GNUNET_STRINGS_relative_time_to_string (exchange->retry_delay,
                                                         GNUNET_YES));
     GNUNET_assert (NULL == exchange->retry_task);
@@ -710,7 +710,7 @@ keys_mgmt_cb (void *cls,
       once = 1;
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                  "Exchange `%s' runs a more recent version of the Taler 
protocol. You may want to update this client.\n",
-                 exchange->uri);
+                 exchange->url);
     }
   }
   expire = TALER_EXCHANGE_check_keys_current (exchange->conn,
@@ -775,7 +775,7 @@ return_result (void *cls)
  * to the exchange, or if it is not acceptable, @a fc is called with
  * NULL for the exchange.
  *
- * @param chosen_exchange URI of the exchange we would like to talk to
+ * @param chosen_exchange URL of the exchange we would like to talk to
  * @param wire_method the wire method we will use with @a chosen_exchange, 
NULL for none
  * @param fc function to call with the handles for the exchange
  * @param fc_cls closure for @a fc
@@ -804,9 +804,9 @@ TMH_EXCHANGES_find_exchange (const char *chosen_exchange,
   /* Check if the exchange is known */
   for (exchange = exchange_head; NULL != exchange; exchange = exchange->next)
     /* test it by checking public key --- FIXME: hostname or public key!?
-       Should probably be URI, not hostname anyway! */
+       Should probably be URL, not hostname anyway! */
   {
-    if (0 == strcmp (exchange->uri,
+    if (0 == strcmp (exchange->url,
                      chosen_exchange))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
@@ -816,13 +816,13 @@ TMH_EXCHANGES_find_exchange (const char *chosen_exchange,
     }
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Comparing chosen exchange url '%s' with known url '%s'.\n",
-                chosen_exchange, exchange->uri);
+                chosen_exchange, exchange->url);
   }
   if (NULL == exchange)
   {
     /* This is a new exchange */
     exchange = GNUNET_new (struct Exchange);
-    exchange->uri = GNUNET_strdup (chosen_exchange);
+    exchange->url = GNUNET_strdup (chosen_exchange);
     exchange->pending = GNUNET_YES;
     GNUNET_CONTAINER_DLL_insert (exchange_head,
                                  exchange_tail,
@@ -916,7 +916,7 @@ accept_exchanges (void *cls,
                   const char *section)
 {
   const struct GNUNET_CONFIGURATION_Handle *cfg = cls;
-  char *uri;
+  char *url;
   char *mks;
   struct Exchange *exchange;
 
@@ -927,16 +927,16 @@ accept_exchanges (void *cls,
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_string (cfg,
                                              section,
-                                             "URI",
-                                             &uri))
+                                             "URL",
+                                             &url))
   {
     GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
                                section,
-                               "URI");
+                               "URL");
     return;
   }
   exchange = GNUNET_new (struct Exchange);
-  exchange->uri = uri;
+  exchange->url = url;
   if (GNUNET_OK ==
       GNUNET_CONFIGURATION_get_value_string (cfg,
                                              section,
@@ -1010,7 +1010,7 @@ TMH_EXCHANGES_init (const struct 
GNUNET_CONFIGURATION_Handle *cfg)
     if (GNUNET_YES != exchange->trusted)
       continue;
     j_exchange = json_pack ("{s:s, s:o}",
-                            "url", exchange->uri,
+                            "url", exchange->url,
                             "master_pub", GNUNET_JSON_from_data_auto 
(&exchange->master_pub));
     GNUNET_assert (0 ==
                    json_array_append_new (trusted_exchanges,
@@ -1070,7 +1070,7 @@ TMH_EXCHANGES_done ()
       GNUNET_SCHEDULER_cancel (exchange->retry_task);
       exchange->retry_task = NULL;
     }
-    GNUNET_free (exchange->uri);
+    GNUNET_free (exchange->url);
     GNUNET_free (exchange);
   }
   GNUNET_CURL_fini (merchant_curl_ctx);
diff --git a/src/backend/taler-merchant-httpd_exchanges.h 
b/src/backend/taler-merchant-httpd_exchanges.h
index 6b763ae..7523e84 100644
--- a/src/backend/taler-merchant-httpd_exchanges.h
+++ b/src/backend/taler-merchant-httpd_exchanges.h
@@ -81,7 +81,7 @@ struct TMH_EXCHANGES_FindOperation;
  * to the exchange, or if it is not acceptable, @a fc is called with
  * NULL for the exchange.
  *
- * @param chosen_exchange URI of the exchange we would like to talk to
+ * @param chosen_exchange URL of the exchange we would like to talk to
  * @param wire_method the wire method we will use with @a chosen_exchange, 
NULL for none
  * @param fc function to call with the handles for the exchange
  * @param fc_cls closure for @a fc
diff --git a/src/backend/taler-merchant-httpd_tip-query.c 
b/src/backend/taler-merchant-httpd_tip-query.c
index 7e236f8..6381c8a 100644
--- a/src/backend/taler-merchant-httpd_tip-query.c
+++ b/src/backend/taler-merchant-httpd_tip-query.c
@@ -71,11 +71,11 @@ MH_handler_tip_query (struct TMH_RequestHandler *rh,
   enum GNUNET_DB_QueryStatus qs;
   struct TALER_Amount tip_amount;
   struct GNUNET_TIME_Absolute tip_timestamp;
-  char *tip_exchange_uri;
+  char *tip_exchange_url;
 
   qs = db->lookup_tip_by_id (db->cls,
                              &tip_id,
-                             &tip_exchange_uri,
+                             &tip_exchange_url,
                              &tip_amount,
                              &tip_timestamp);
 
@@ -91,7 +91,7 @@ MH_handler_tip_query (struct TMH_RequestHandler *rh,
       return TMH_RESPONSE_reply_json_pack (connection,
                                            MHD_HTTP_OK,
                                            "{s:s, s:s}",
-                                           "exchange", tip_exchange_uri,
+                                           "exchange", tip_exchange_url,
                                            "timestamp", 
GNUNET_JSON_from_time_abs (tip_timestamp),
                                            "amount", TALER_JSON_from_amount 
(&tip_amount));
   }
diff --git a/src/lib/merchant_api_common.c b/src/lib/merchant_api_common.c
index 12bc81d..c5b4a78 100644
--- a/src/lib/merchant_api_common.c
+++ b/src/lib/merchant_api_common.c
@@ -29,7 +29,7 @@
  *
  * @param base_url base URL of the exchange (i.e. "http://exchange/";)
  * @param path Taler API path (i.e. "/reserve/withdraw")
- * @return the full URI to use with cURL
+ * @return the full URL to use with cURL
  */
 char *
 MAH_path_to_url_ (const char *base_url,
diff --git a/src/lib/merchant_api_common.h b/src/lib/merchant_api_common.h
index 09696e3..c94287f 100644
--- a/src/lib/merchant_api_common.h
+++ b/src/lib/merchant_api_common.h
@@ -27,7 +27,7 @@
  *
  * @param base_url base URL of the exchange (i.e. "http://exchange/";)
  * @param path Taler API path (i.e. "/reserve/withdraw")
- * @return the full URI to use with cURL
+ * @return the full URL to use with cURL
  */
 char *
 MAH_path_to_url_ (const char *base_url,
diff --git a/src/lib/merchant_api_tip_authorize.c 
b/src/lib/merchant_api_tip_authorize.c
index a7aa4f5..e9b263b 100644
--- a/src/lib/merchant_api_tip_authorize.c
+++ b/src/lib/merchant_api_tip_authorize.c
@@ -85,11 +85,11 @@ check_ok (struct TALER_MERCHANT_TipAuthorizeOperation *tao,
 {
   struct GNUNET_HashCode tip_id;
   struct GNUNET_TIME_Absolute tip_expiration;
-  const char *exchange_uri;
+  const char *exchange_url;
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_absolute_time ("expiration", &tip_expiration),
     GNUNET_JSON_spec_fixed_auto ("tip_id", &tip_id),
-    GNUNET_JSON_spec_string ("exchange_url", &exchange_uri),
+    GNUNET_JSON_spec_string ("exchange_url", &exchange_url),
     GNUNET_JSON_spec_end()
   };
 
@@ -106,7 +106,7 @@ check_ok (struct TALER_MERCHANT_TipAuthorizeOperation *tao,
            TALER_JSON_get_error_code (json),
            &tip_id,
            tip_expiration,
-           exchange_uri);
+           exchange_url);
   tao->cb = NULL; /* do not call twice */
   GNUNET_JSON_parse_free (spec);
   return GNUNET_OK;
@@ -236,7 +236,7 @@ TALER_MERCHANT_tip_authorize (struct GNUNET_CURL_Context 
*ctx,
   }
   json_decref (te_obj);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Requesting URI '%s'\n",
+              "Requesting URL '%s'\n",
               tao->url);
   eh = curl_easy_init ();
   GNUNET_assert (CURLE_OK ==
diff --git a/src/lib/test_merchant_api.conf b/src/lib/test_merchant_api.conf
index 67ef46b..924aaa5 100644
--- a/src/lib/test_merchant_api.conf
+++ b/src/lib/test_merchant_api.conf
@@ -45,7 +45,7 @@ DEFAULT_MAX_DEPOSIT_FEE = EUR:0.10
 # Enable 'test' for testing of the actual coin operations.
 ENABLE = YES
 
-BANK_URI = http://localhost:8083/
+BANK_URL = http://localhost:8083/
 
 # Fees for the forseeable future...
 # If you see this after 2017, update to match the next 10 years...
@@ -72,7 +72,7 @@ CLOSING-FEE-2026 = EUR:0.01
 
 
 [merchant-exchange-test]
-URI = http://localhost:8084/
+URL = http://localhost:8084/
 MASTER_KEY = 98NJW3CQHZQGQXTY3K85K531XKPAPAVV4Q5V8PYYRR00NJGZWNVG
 
 [merchant-instance-default]
@@ -114,10 +114,10 @@ TEST_RESPONSE_FILE = 
${TALER_CONFIG_HOME}/merchant/wire/test.json
 # Informal name of the auditor. Just for the user.
 NAME = European Central Bank
 
-# URI of the auditor (especially for in the future, when the
+# URL of the auditor (especially for in the future, when the
 # auditor offers an automated issue reporting system).
 # Not really used today.
-URI = http://taler.ezb.eu/
+URL = http://taler.ezb.eu/
 
 # This is the important bit: the signing key of the auditor.
 PUBLIC_KEY = 9QXF7XY7E9VPV47B5Z806NDFSX2VJ79SVHHD29QEQ3BG31ANHZ60
@@ -163,7 +163,7 @@ DB_CONN_STR = "postgres:///talercheck"
 TEST_RESPONSE_FILE = ${TALER_CONFIG_HOME}/test.json
 
 # What is the main website of the bank?
-BANK_URI = "http://localhost:8083/";
+BANK_URL = "http://localhost:8083/";
 # From which account at the 'bank' should outgoing wire transfers be made?
 BANK_ACCOUNT_NUMBER = 2
 
diff --git 
a/src/lib/test_merchant_api_home/.config/taler/merchant/wire/test.json 
b/src/lib/test_merchant_api_home/.config/taler/merchant/wire/test.json
index 99c9c66..6898b00 100644
--- a/src/lib/test_merchant_api_home/.config/taler/merchant/wire/test.json
+++ b/src/lib/test_merchant_api_home/.config/taler/merchant/wire/test.json
@@ -1,5 +1,5 @@
 {
   "type":"test",
-  "bank_uri":"http://localhost:8083/";,
+  "bank_url":"http://localhost:8083/";,
   "account_number":62
 }
diff --git a/src/lib/test_merchant_api_home/.config/taler/test.json 
b/src/lib/test_merchant_api_home/.config/taler/test.json
index 6c8c61f..74cdc92 100644
--- a/src/lib/test_merchant_api_home/.config/taler/test.json
+++ b/src/lib/test_merchant_api_home/.config/taler/test.json
@@ -1,8 +1,8 @@
 {
   "name": "The exchange",
   "account_number": 3,
-  "bank_uri": "http://localhost:8083/";,
+  "bank_url": "http://localhost:8083/";,
   "salt": 
"6259MV4W9V8D2A75RSGGPKYHQRXRPQZ33EBG263JZRJ6SA5HK0RRKHV70TNA1RVRG77M57CCFVSK2B0EJN3SR8S21F0ZX2MR9DNVG50",
   "type": "test",
   "sig": 
"8C3D3J816S29AA2AJ7P9TS6W13KFNFS2RCVYJEWRBNHRRMTTRAWKY7WA1N3G54E4K3XAC2HN6JDHS42TWR5315J34JHHCKV618K221G"
-}
\ No newline at end of file
+}
diff --git a/src/merchant-tools/README b/src/merchant-tools/README
index 993a87e..d84ca59 100644
--- a/src/merchant-tools/README
+++ b/src/merchant-tools/README
@@ -28,7 +28,7 @@ exchange = http://localexchange/
 # where on this machine the merchant listens
 merchant = http://localshop/
 
-# bank's URI of the customer who withdraws coins.
+# bank's URL of the customer who withdraws coins.
 # Must be known by the exchange.
 bank = http://localbank/
 

diff --git a/src/backend/taler-merchant-httpd_tip-pickup.c 
b/src/backend/taler-merchant-httpd_tip-pickup.c
index 79248d7..3cc73af 100644
--- a/src/backend/taler-merchant-httpd_tip-pickup.c
+++ b/src/backend/taler-merchant-httpd_tip-pickup.c
@@ -79,9 +79,9 @@ struct PickupContext
   void *json_parse_context;
 
   /**
    * URI of the exchange this tip uses.
    */
-  char *exchange_uri;
+  char *exchange_url;
 
   /**
    * Operation we run to find the exchange (and get its /keys).
@@ -162,7 +162,7 @@ pickup_cleanup (struct TM_HandlerContext *hc)
     pc->fo = NULL;
   }
   TMH_PARSE_post_cleanup_callback (pc->json_parse_context);
-  GNUNET_free_non_null (pc->exchange_uri);
+  GNUNET_free_non_null (pc->exchange_url);
   GNUNET_free (pc);
 }
 
@@ -379,7 +379,7 @@ prepare_pickup (struct PickupContext *pc)
 
   qs = db->lookup_tip_by_id (db->cls,
                              &pc->tip_id,
-                             &pc->exchange_uri,
+                             &pc->exchange_url,
                              NULL, NULL);
   if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT != qs)
   {
@@ -409,10 +409,10 @@ prepare_pickup (struct PickupContext *pc)
     return TMH_RESPONSE_reply_rc (pc->connection,
                                  response_code,
                                  ec,
-                                 "Could not determine exchange URI for the 
given tip id");
+                                 "Could not determine exchange URL for the 
given tip id");
 
   }
-  pc->fo = TMH_EXCHANGES_find_exchange (pc->exchange_uri,
+  pc->fo = TMH_EXCHANGES_find_exchange (pc->exchange_url,
                                        NULL,
                                        &exchange_found_cb,
                                        pc);
@@ -79,9 +79,9 @@ struct PickupContext
 
   /**
-   * URI of the exchange this tip uses.
+   * URL of the exchange this tip uses.
    */
diff --git a/src/backend/taler-merchant-httpd_track-transfer.c 
b/src/backend/taler-merchant-httpd_track-transfer.c
index 6297c8f..197947f 100644
--- a/src/backend/taler-merchant-httpd_track-transfer.c
+++ b/src/backend/taler-merchant-httpd_track-transfer.c
@@ -91,9 +91,9 @@ struct TrackTransferContext
   struct GNUNET_SCHEDULER_Task *timeout_task;
 
   /**
    * URI of the exchange.
    */
-  char *uri;
+  char *url;
 
   /**
    * Wire method used for the transfer.
@@ -183,10 +183,10 @@ free_transfer_track_context (struct TrackTransferContext 
*rctx)
     TALER_EXCHANGE_track_transfer_cancel (rctx->wdh);
     rctx->wdh = NULL;
   }
-  if (NULL != rctx->uri)
+  if (NULL != rctx->url)
   {
-    GNUNET_free (rctx->uri);
-    rctx->uri = NULL;
+    GNUNET_free (rctx->url);
+    rctx->url = NULL;
   }
   if (NULL != rctx->wire_method)
   {
@@ -620,7 +620,7 @@ wire_transfer_cb (void *cls,
   for (unsigned int i=0;i<MAX_RETRIES;i++)
   {
     qs = db->store_transfer_to_proof (db->cls,
-                                     rctx->uri,
+                                     rctx->url,
                                      &rctx->wtid,
                                      execution_time,
                                      exchange_pub,
@@ -878,7 +878,7 @@ MH_handler_track_transfer (struct TMH_RequestHandler *rh,
 {
   struct TrackTransferContext *rctx;
   const char *str;
-  const char *uri;
+  const char *url;
   const char *instance_str;
   const char *wire_method;
   int ret;
@@ -928,14 +928,14 @@ MH_handler_track_transfer (struct TMH_RequestHandler *rh,
     return MHD_YES; /* still work in progress */
   }
 
-  uri = MHD_lookup_connection_value (connection,
+  url = MHD_lookup_connection_value (connection,
                                      MHD_GET_ARGUMENT_KIND,
                                      "exchange");
-  if (NULL == uri)
+  if (NULL == url)
     return TMH_RESPONSE_reply_arg_missing (connection,
                                           TALER_EC_PARAMETER_MISSING,
                                            "exchange");
-  rctx->uri = GNUNET_strdup (uri);
+  rctx->url = GNUNET_strdup (url);
 
   wire_method = MHD_lookup_connection_value (connection,
                                             MHD_GET_ARGUMENT_KIND,
@@ -988,7 +988,7 @@ MH_handler_track_transfer (struct TMH_RequestHandler *rh,
 
   /* Check if reply is already in database! */
   qs = db->find_proof_by_wtid (db->cls,
-                              rctx->uri,
+                              rctx->url,
                               &rctx->wtid,
                               &proof_cb,
                               rctx);
@@ -1022,7 +1022,7 @@ MH_handler_track_transfer (struct TMH_RequestHandler *rh,
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Suspending /track/transfer handling while working with the 
exchange\n");
   MHD_suspend_connection (connection);
-  rctx->fo = TMH_EXCHANGES_find_exchange (uri,
+  rctx->fo = TMH_EXCHANGES_find_exchange (url,
                                           NULL,
                                           
@@ -91,9 +91,9 @@ struct TrackTransferContext
 
   /**
-   * URI of the exchange.
+   * URL of the exchange.
    */
&process_track_transfer_with_exchange,
                                           rctx);
diff --git a/src/lib/merchant_api_history.c b/src/lib/merchant_api_history.c
index efc20be..8aa38dc 100644
--- a/src/lib/merchant_api_history.c
+++ b/src/lib/merchant_api_history.c
@@ -110,7 +110,7 @@ history_raw_cb (void *cls,
     return;
   case MHD_HTTP_INTERNAL_SERVER_ERROR:
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-               "/history URI not found\n");
+               "/history URL not found\n");
     break;
   case MHD_HTTP_BAD_REQUEST:
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -137,7 +137,7 @@ history_raw_cb (void *cls,
  * Issue a /history request to the backend.
  *
  * @param ctx execution context
  * @param backend_uri base URL of the merchant backend
  * @param instance which merchant instance is performing this call
  * @param start return `delta` records starting from position `start`.
  * If given as zero, then no initial skip of `start` records is done.
@@ -149,7 +149,7 @@ history_raw_cb (void *cls,
  */
 struct TALER_MERCHANT_HistoryOperation *
 TALER_MERCHANT_history (struct GNUNET_CURL_Context *ctx,
-                        const char *backend_uri,
+                        const char *backend_url,
                         const char *instance,
                         unsigned int start,
                         unsigned int delta,
@@ -167,7 +167,7 @@ TALER_MERCHANT_history (struct GNUNET_CURL_Context *ctx,
   ho->cb = history_cb;
   ho->cb_cls = history_cb_cls;
   seconds = date.abs_value_us / 1000LL / 1000LL;
-  base = MAH_path_to_url_ (backend_uri,
+  base = MAH_path_to_url_ (backend_url,
                           "/history");
   GNUNET_asprintf (&ho->url,
                    "%s?date=%llu&instance=%s&start=%d&delta=%d",
@@ -137,7 +137,7 @@ history_raw_cb (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri base URL of the merchant backend
+ * @param backend_url base URL of the merchant backend
  * @param instance which merchant instance is performing this call
  * @param start return `delta` records starting from position `start`.
diff --git a/src/lib/merchant_api_pay_abort.c b/src/lib/merchant_api_pay_abort.c
index 7616374..d9fb2e1 100644
--- a/src/lib/merchant_api_pay_abort.c
+++ b/src/lib/merchant_api_pay_abort.c
@@ -254,7 +254,7 @@ handle_pay_finished (void *cls,
  * by the logic using this library.
  *
  * @param ctx the execution loop context
  * @param merchant_uri base URI of the merchant's backend
  * @param instance which merchant instance will receive this payment
  * @param h_contract_terms hashcode of the proposal being paid
  * @param amount total value of the contract to be paid to the merchant
@@ -274,7 +274,7 @@ handle_pay_finished (void *cls,
  */
 struct TALER_MERCHANT_Pay *
 TALER_MERCHANT_pay_wallet (struct GNUNET_CURL_Context *ctx,
-                          const char *merchant_uri,
+                          const char *merchant_url,
                           const char *instance,
                            const struct GNUNET_HashCode *h_contract_terms,
                           const struct TALER_Amount *amount,
@@ -440,7 +440,7 @@ TALER_MERCHANT_pay_wallet (struct GNUNET_CURL_Context *ctx,
   ph->ctx = ctx;
   ph->cb = pay_cb;
   ph->cb_cls = pay_cb_cls;
-  ph->url = MAH_path_to_url_ (merchant_uri,
+  ph->url = MAH_path_to_url_ (merchant_url,
                              "/pay");
   ph->num_coins = num_coins;
   ph->coins = GNUNET_new_array (num_coins,
@@ -254,7 +254,7 @@ handle_pay_finished (void *cls,
  *
  * @param ctx the execution loop context
- * @param merchant_uri base URI of the merchant's backend
+ * @param merchant_url base URL of the merchant's backend
  * @param instance which merchant instance will receive this payment
  * @param h_contract_terms hashcode of the proposal being paid
diff --git a/src/lib/merchant_api_proposal.c b/src/lib/merchant_api_proposal.c
index 17b2315..936e0eb 100644
--- a/src/lib/merchant_api_proposal.c
+++ b/src/lib/merchant_api_proposal.c
@@ -75,7 +75,7 @@ struct TALER_MERCHANT_ProposalOperation
 struct TALER_MERCHANT_ProposalLookupOperation
 {
   /**
-   * Full URI, includes "/proposal".
+   * Full URL, includes "/proposal".
    */
   char *url;
 
@@ -192,7 +192,7 @@ handle_proposal_finished (void *cls,
  * POST an order to the backend and receives the related proposal.
  *
  * @param ctx execution context
  * @param backend_uri URI of the backend
  * @param order basic information about this purchase, to be extended by the
  * backend
  * @param proposal_cb the callback to call when a reply for this request is
@@ -202,7 +202,7 @@ handle_proposal_finished (void *cls,
  */
 struct TALER_MERCHANT_ProposalOperation *
 TALER_MERCHANT_order_put (struct GNUNET_CURL_Context *ctx,
-                          const char *backend_uri,
+                          const char *backend_url,
                           const json_t *order,
                           TALER_MERCHANT_ProposalCallback proposal_cb,
                           void *proposal_cb_cls)
@@ -215,7 +215,7 @@ TALER_MERCHANT_order_put (struct GNUNET_CURL_Context *ctx,
   po->ctx = ctx;
   po->cb = proposal_cb;
   po->cb_cls = proposal_cb_cls;
-  po->url = MAH_path_to_url_ (backend_uri,
+  po->url = MAH_path_to_url_ (backend_url,
                              "/order");
   req = json_pack ("{s:O}",
                    "order", (json_t *) order);
@@ -349,7 +349,7 @@ handle_proposal_lookup_finished (void *cls,
  * retrieve a proposal data by providing its transaction id.
  *
  * @param ctx execution context
  * @param backend_uri base URL of the merchant backend
  * @param order_id order id used to perform the lookup
  * @param nonce nonce used to perform the lookup
  * @param plo_cb callback which will work the response gotten from the backend
@@ -358,7 +358,7 @@ handle_proposal_lookup_finished (void *cls,
  */
 struct TALER_MERCHANT_ProposalLookupOperation *
 TALER_MERCHANT_proposal_lookup (struct GNUNET_CURL_Context *ctx,
-                                const char *backend_uri,
+                                const char *backend_url,
                                 const char *order_id,
                                 const char *instance,
                                 const struct GNUNET_CRYPTO_EddsaPublicKey 
*nonce,
@@ -373,7 +373,7 @@ TALER_MERCHANT_proposal_lookup (struct GNUNET_CURL_Context 
*ctx,
   plo->ctx = ctx;
   plo->cb = plo_cb;
   plo->cb_cls = plo_cb_cls;
-  base = MAH_path_to_url_ (backend_uri,
+  base = MAH_path_to_url_ (backend_url,
                           "/public/proposal");
   if (NULL != nonce)
   {
@@ -192,7 +192,7 @@ handle_proposal_finished (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri URI of the backend
+ * @param backend_url URL of the backend
  * @param order basic information about this purchase, to be extended by the
  * backend
@@ -349,7 +349,7 @@ handle_proposal_lookup_finished (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri base URL of the merchant backend
+ * @param backend_url base URL of the merchant backend
  * @param order_id order id used to perform the lookup
  * @param nonce nonce used to perform the lookup
diff --git a/src/lib/merchant_api_refund.c b/src/lib/merchant_api_refund.c
index 75a7899..0307c42 100644
--- a/src/lib/merchant_api_refund.c
+++ b/src/lib/merchant_api_refund.c
@@ -170,7 +170,7 @@ TALER_MERCHANT_refund_increase_cancel (struct 
TALER_MERCHANT_RefundIncreaseOpera
  * Increase the refund associated to a order
  *
  * @param ctx the CURL context used to connect to the backend
  * @param backend_uri backend's base URL, including final "/"
  * @param order_id id of the order whose refund is to be increased
  * @param refund amount to which increase the refund
  * @param reason human-readable reason justifying the refund
@@ -180,7 +180,7 @@ TALER_MERCHANT_refund_increase_cancel (struct 
TALER_MERCHANT_RefundIncreaseOpera
  */
 struct TALER_MERCHANT_RefundIncreaseOperation *
 TALER_MERCHANT_refund_increase (struct GNUNET_CURL_Context *ctx,
-                                const char *backend_uri,
+                                const char *backend_url,
                                 const char *order_id,
                                 const struct TALER_Amount *refund,
                                 const char *reason,
@@ -196,7 +196,7 @@ TALER_MERCHANT_refund_increase (struct GNUNET_CURL_Context 
*ctx,
   rio->ctx = ctx;
   rio->cb = cb;
   rio->cb_cls = cb_cls;
-  rio->url = MAH_path_to_url_ (backend_uri,
+  rio->url = MAH_path_to_url_ (backend_url,
                               "/refund");
   req = json_pack ("{s:o, s:s, s:s, s:s}",
                    "refund", TALER_JSON_from_amount (refund),
@@ -302,7 +302,7 @@ handle_refund_lookup_finished (void *cls,
  * Does a GET /refund.
  *
  * @param ctx execution context
  * @param backend_uri base URL of the merchant backend
  * @param order_id order id used to perform the lookup
  * @param cb callback which will work the response gotten from the backend
  * @param cb_cls closure to pass to the callback
@@ -310,7 +310,7 @@ handle_refund_lookup_finished (void *cls,
  */
 struct TALER_MERCHANT_RefundLookupOperation *
 TALER_MERCHANT_refund_lookup (struct GNUNET_CURL_Context *ctx,
-                              const char *backend_uri,
+                              const char *backend_url,
                               const char *order_id,
                               const char *instance,
                               TALER_MERCHANT_RefundLookupCallback cb,
@@ -326,7 +326,7 @@ TALER_MERCHANT_refund_lookup (struct GNUNET_CURL_Context 
*ctx,
 
   GNUNET_asprintf (&rlo->url,
                    "%s/public/refund?instance=%s&order_id=%s",
-                   backend_uri,
+                   backend_url,
                    instance,
                    order_id);
   eh = curl_easy_init ();
@@ -170,7 +170,7 @@ TALER_MERCHANT_refund_increase_cancel (struct 
  *
  * @param ctx the CURL context used to connect to the backend
- * @param backend_uri backend's base URL, including final "/"
+ * @param backend_url backend's base URL, including final "/"
  * @param order_id id of the order whose refund is to be increased
  * @param refund amount to which increase the refund
@@ -302,7 +302,7 @@ handle_refund_lookup_finished (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri base URL of the merchant backend
+ * @param backend_url base URL of the merchant backend
  * @param order_id order id used to perform the lookup
  * @param cb callback which will work the response gotten from the backend
diff --git a/src/lib/merchant_api_tip_pickup.c 
b/src/lib/merchant_api_tip_pickup.c
index e5343e3..4ca3b80 100644
--- a/src/lib/merchant_api_tip_pickup.c
+++ b/src/lib/merchant_api_tip_pickup.c
@@ -211,7 +211,7 @@ handle_tip_pickup_finished (void *cls,
  * that a customer wants to pick up a tip.
  *
  * @param ctx execution context
  * @param backend_uri base URL of the merchant backend
  * @param tip_id unique identifier for the tip
  * @param num_planches number of planchets provided in @a planchets
  * @param planchets array of planchets to be signed into existence for the tip
@@ -221,7 +221,7 @@ handle_tip_pickup_finished (void *cls,
  */
 struct TALER_MERCHANT_TipPickupOperation *
 TALER_MERCHANT_tip_pickup (struct GNUNET_CURL_Context *ctx,
-                           const char *backend_uri,
+                           const char *backend_url,
                            const struct GNUNET_HashCode *tip_id,
                            unsigned int num_planchets,
                            struct TALER_PlanchetDetail *planchets,
@@ -282,7 +282,7 @@ TALER_MERCHANT_tip_pickup (struct GNUNET_CURL_Context *ctx,
   tpo->ctx = ctx;
   tpo->cb = pickup_cb;
   tpo->cb_cls = pickup_cb_cls;
-  tpo->url = MAH_path_to_url_ (backend_uri,
+  tpo->url = MAH_path_to_url_ (backend_url,
                                "/public/tip-pickup");
   if (NULL == (tpo->json_enc =
                json_dumps (tp_obj,
@@ -296,7 +296,7 @@ TALER_MERCHANT_tip_pickup (struct GNUNET_CURL_Context *ctx,
   }
   json_decref (tp_obj);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Requesting URI '%s'\n",
+              "Requesting URL '%s'\n",
               tpo->url);
   eh = curl_easy_init ();
   GNUNET_assert (CURLE_OK ==
@@ -211,7 +211,7 @@ handle_tip_pickup_finished (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri base URL of the merchant backend
+ * @param backend_url base URL of the merchant backend
  * @param tip_id unique identifier for the tip
  * @param num_planches number of planchets provided in @a planchets
diff --git a/src/lib/merchant_api_track_transaction.c 
b/src/lib/merchant_api_track_transaction.c
index 5357d37..d48916a 100644
--- a/src/lib/merchant_api_track_transaction.c
+++ b/src/lib/merchant_api_track_transaction.c
@@ -129,7 +129,7 @@ handle_track_transaction_finished (void *cls,
  * Request backend to return transactions associated with a given wtid.
  *
  * @param ctx execution context
  * @param backend_uri base URI of the backend
  * @param instance which merchant instance is going to be tracked
  * @param order_id order id pointing to the transaction being tracked
  * @param track_transaction_cb the callback to call when a reply for this 
request is available
@@ -138,7 +138,7 @@ handle_track_transaction_finished (void *cls,
  */
 struct TALER_MERCHANT_TrackTransactionHandle *
 TALER_MERCHANT_track_transaction (struct GNUNET_CURL_Context *ctx,
-                                  const char *backend_uri,
+                                  const char *backend_url,
                                   const char *instance,
                                   const char *order_id,
                                   TALER_MERCHANT_TrackTransactionCallback 
track_transaction_cb,
@@ -152,7 +152,7 @@ TALER_MERCHANT_track_transaction (struct 
GNUNET_CURL_Context *ctx,
   tdo->ctx = ctx;
   tdo->cb = track_transaction_cb;
   tdo->cb_cls = track_transaction_cb_cls;
-  base = MAH_path_to_url_ (backend_uri,
+  base = MAH_path_to_url_ (backend_url,
                           "/track/transaction");
   GNUNET_asprintf (&tdo->url,
                    "%s?order_id=%s&instance=%s",
@@ -161,7 +161,7 @@ TALER_MERCHANT_track_transaction (struct 
GNUNET_CURL_Context *ctx,
                    instance);
   GNUNET_free (base);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Requesting URI '%s'\n",
+              "Requesting URL '%s'\n",
               tdo->url);
   eh = curl_easy_init ();
   GNUNET_assert (CURLE_OK ==
@@ -129,7 +129,7 @@ handle_track_transaction_finished (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri base URI of the backend
+ * @param backend_url base URL of the backend
  * @param instance which merchant instance is going to be tracked
  * @param order_id order id pointing to the transaction being tracked
diff --git a/src/lib/merchant_api_track_transfer.c 
b/src/lib/merchant_api_track_transfer.c
index 660d4e1..c55d544 100644
--- a/src/lib/merchant_api_track_transfer.c
+++ b/src/lib/merchant_api_track_transfer.c
@@ -214,22 +214,22 @@ handle_track_transfer_finished (void *cls,
  * Request backend to return transfers associated with a given wtid.
  *
  * @param ctx execution context
  * @param backend_uri base URI of the backend
  * @param instance which merchant instance is going to be tracked
  * @param wire_method wire method used for the wire transfer
  * @param wtid base32 string indicating a wtid
- * @param exchange_uri base URL of the exchange in charge of returning the 
wanted information
+ * @param exchange_url base URL of the exchange in charge of returning the 
wanted information
  * @param track_transfer_cb the callback to call when a reply for this request 
is available
  * @param track_transfer_cb_cls closure for @a contract_cb
  * @return a handle for this request
  */
 struct TALER_MERCHANT_TrackTransferHandle *
 TALER_MERCHANT_track_transfer (struct GNUNET_CURL_Context *ctx,
-                               const char *backend_uri,
+                               const char *backend_url,
                                const char *instance,
                               const char *wire_method,
                                const struct TALER_WireTransferIdentifierRawP 
*wtid,
-                               const char *exchange_uri,
+                               const char *exchange_url,
                                TALER_MERCHANT_TrackTransferCallback 
track_transfer_cb,
                                void *track_transfer_cb_cls)
 {
@@ -244,14 +244,14 @@ TALER_MERCHANT_track_transfer (struct GNUNET_CURL_Context 
*ctx,
   tdo->ctx = ctx;
   tdo->cb = track_transfer_cb; // very last to be called
   tdo->cb_cls = track_transfer_cb_cls;
-  /* TODO: do we need to escape 'exchange_uri' here? */
-  base = MAH_path_to_url_ (backend_uri,
+  /* TODO: do we need to escape 'exchange_url' here? */
+  base = MAH_path_to_url_ (backend_url,
                           "/track/transfer");
   GNUNET_asprintf (&tdo->url,
                    "%s?wtid=%s&exchange=%s&instance=%s&wire_method=%s",
                    base,
                    wtid_str,
-                   exchange_uri,
+                   exchange_url,
                   instance,
                   wire_method);
   GNUNET_free (base);
@@ -214,22 +214,22 @@ handle_track_transfer_finished (void *cls,
  *
  * @param ctx execution context
- * @param backend_uri base URI of the backend
+ * @param backend_url base URL of the backend
  * @param instance which merchant instance is going to be tracked
  * @param wire_method wire method used for the wire transfer
diff --git a/src/lib/test_merchant_api.c b/src/lib/test_merchant_api.c
index 40b1f60..d4f605f 100644
--- a/src/lib/test_merchant_api.c
+++ b/src/lib/test_merchant_api.c
@@ -2195,7 +2195,7 @@ track_transaction_cb (void *cls,
  * @param ec taler-specific error code
  * @param tip_id which tip ID should be used to pickup the tip
  * @param tip_expiration when does the tip expire (needs to be picked up 
before this time)
  * @param exchange_uri at what exchange can the tip be picked up
  */
 static void
 tip_authorize_cb (void *cls,
@@ -2203,7 +2203,7 @@ tip_authorize_cb (void *cls,
                   enum TALER_ErrorCode ec,
                   const struct GNUNET_HashCode *tip_id,
                   struct GNUNET_TIME_Absolute tip_expiration,
-                  const char *exchange_uri)
+                  const char *exchange_url)
 {
   struct InterpreterState *is = cls;
   struct Command *cmd = &is->commands[is->ip];
@@ -2232,12 +2232,12 @@ tip_authorize_cb (void *cls,
   if ( (MHD_HTTP_OK == http_status) &&
        (TALER_EC_NONE == ec) )
   {
-    if (0 != strcmp (exchange_uri,
+    if (0 != strcmp (exchange_url,
                      EXCHANGE_URL))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                   "Unexpected exchange URL %s to command %s\n",
-                  exchange_uri,
+                  exchange_url,
                   cmd->label);
       fail (is);
       return;
@@ -2195,7 +2195,7 @@ track_transaction_cb (void *cls,
  * @param tip_expiration when does the tip expire (needs to be picked up 
before this time)
- * @param exchange_uri at what exchange can the tip be picked up
+ * @param exchange_url at what exchange can the tip be picked up
  */
 static void
-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]